@@ -2,18 +2,20 @@
 /*
  *  Copyright © 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -40,13 +42,10 @@ struct _EphyAboutHandler {
   EphySMaps *smaps;
 };
 
-G_DEFINE_TYPE (EphyAboutHandler, ephy_about_handler, G_TYPE_OBJECT)
-
-
-#define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 9
-
 #define EPHY_PAGE_TEMPLATE_ABOUT_CSS        "ephy-resource:///org/gnome/epiphany/page-templates/about.css"
 
+G_DEFINE_TYPE (EphyAboutHandler, ephy_about_handler, G_TYPE_OBJECT)
+
 static void
 ephy_about_handler_finalize (GObject *object)
 {
@@ -92,114 +91,6 @@ ephy_about_handler_finish_request (WebKitURISchemeRequest *request,
   g_object_unref (stream);
 }
 
-typedef struct {
-  EphyAboutHandler *handler;
-  WebKitURISchemeRequest *request;
-} EphyAboutRequest;
-
-static EphyAboutRequest *
-ephy_about_request_new (EphyAboutHandler       *handler,
-                        WebKitURISchemeRequest *request)
-{
-  EphyAboutRequest *about_request;
-
-  about_request = g_slice_new (EphyAboutRequest);
-  about_request->handler = g_object_ref (handler);
-  about_request->request = g_object_ref (request);
-
-  return about_request;
-}
-
-static void
-ephy_about_request_free (EphyAboutRequest *about_request)
-{
-  g_object_unref (about_request->handler);
-  g_object_unref (about_request->request);
-
-  g_slice_free (EphyAboutRequest, about_request);
-}
-
-static void
-get_plugins_cb (WebKitWebContext *web_context,
-                GAsyncResult     *result,
-                EphyAboutRequest *about_request)
-{
-  GString *data_str;
-  gsize data_length;
-  GList *plugin_list, *p;
-  gboolean enabled;
-
-  enabled = g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_PLUGINS);
-
-  data_str = g_string_new ("<html>");
-  g_string_append_printf (data_str, "<head><title>%s</title>"
-                          "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
-                          "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
-                          "</head><body>",
-                          _("Installed plugins"));
-  g_string_append_printf (data_str, "<h1>%s</h1>", _("Plugins"));
-
-  if (!enabled)
-    g_string_append_printf (data_str, "<p><b>%s</b></p>", _("Plugins are disabled in the preferences"));
-
-  plugin_list = webkit_web_context_get_plugins_finish (web_context, result, NULL);
-  for (p = plugin_list; p; p = p->next) {
-    WebKitPlugin *plugin = WEBKIT_PLUGIN (p->data);
-    GList *m, *mime_types;
-
-    /* TODO: Enable/disable plugins in WebKit2 */
-    g_string_append_printf (data_str, "<h2>%s</h2>%s<br>%s: <b>%s</b>"  \
-                            "<table id=\"plugin-table\">"               \
-                            "  <thead><tr><th>%s</th><th>%s</th><th>%s</th></tr></thead><tbody>",
-                            webkit_plugin_get_name (plugin),
-                            webkit_plugin_get_description (plugin),
-                            _("Enabled"), /*webkit_plugin_get_enabled (plugin) && */ enabled ? _("Yes") : _("No"),
-                            _("MIME type"), _("Description"), _("Suffixes"));
-
-    mime_types = webkit_plugin_get_mime_info_list (plugin);
-
-    for (m = mime_types; m; m = m->next) {
-      WebKitMimeInfo *mime_info = (WebKitMimeInfo *)m->data;
-      const gchar * const *extensions;
-      guint i;
-
-      g_string_append_printf (data_str, "<tr><td>%s</td><td>%s</td><td>",
-                              webkit_mime_info_get_mime_type (mime_info),
-                              webkit_mime_info_get_description (mime_info));
-
-      extensions = webkit_mime_info_get_extensions (mime_info);
-      for (i = 0; extensions && extensions[i] != NULL; i++)
-        g_string_append_printf (data_str, "%s%c", extensions[i],
-                                extensions[i + 1] ? ',' : ' ');
-
-      g_string_append (data_str, "</td></tr>");
-    }
-
-    g_string_append (data_str, "</tbody></table>");
-  }
-  g_string_append (data_str, "</body></html>");
-
-  g_list_free_full (plugin_list, g_object_unref);
-
-  data_length = data_str->len;
-  ephy_about_handler_finish_request (about_request->request, g_string_free (data_str, FALSE), data_length);
-  ephy_about_request_free (about_request);
-}
-
-static gboolean
-ephy_about_handler_handle_plugins (EphyAboutHandler       *handler,
-                                   WebKitURISchemeRequest *request)
-{
-  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
-
-  webkit_web_context_get_plugins (ephy_embed_shell_get_web_context (shell),
-                                  NULL,
-                                  (GAsyncReadyCallback)get_plugins_cb,
-                                  ephy_about_request_new (handler, request));
-
-  return TRUE;
-}
-
 static void
 handle_memory_finished_cb (EphyAboutHandler       *handler,
                            GAsyncResult           *result,
@@ -270,8 +161,8 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
   version = g_strdup_printf (_("Version %s"), VERSION);
 
   icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                          "web-browser",
-                                          256,
+                                          "org.gnome.Epiphany",
+                                          512,
                                           GTK_ICON_LOOKUP_GENERIC_FALLBACK);
 
   data = g_strdup_printf ("<html><head><title>%s</title>"
@@ -405,22 +296,44 @@ ephy_about_handler_handle_applications (EphyAboutHandler       *handler,
   return TRUE;
 }
 
+typedef struct {
+  char *url;
+  time_t mtime;
+} GetSnapshotPathAsyncData;
+
+static void
+got_snapshot_path_for_url_cb (EphySnapshotService      *service,
+                              GAsyncResult             *result,
+                              GetSnapshotPathAsyncData *data)
+{
+  char *snapshot;
+  GError *error = NULL;
+
+  snapshot = ephy_snapshot_service_get_snapshot_path_for_url_finish (service, result, &error);
+  if (snapshot) {
+    ephy_embed_shell_set_thumbnail_path (ephy_embed_shell_get_default (), data->url, data->mtime, snapshot);
+    g_free (snapshot);
+  } else {
+    /* Bad luck, not something to warn about. */
+    g_info ("Failed to get snapshot for URL %s: %s", data->url, error->message);
+    g_error_free (error);
+  }
+  g_free (data->url);
+  g_free (data);
+}
+
 static void
 history_service_query_urls_cb (EphyHistoryService     *history,
                                gboolean                success,
                                GList                  *urls,
                                WebKitURISchemeRequest *request)
 {
-  EphySnapshotService *snapshot_service;
-  EphyEmbedShell *shell;
+  EphySnapshotService *snapshot_service = ephy_snapshot_service_get_default ();
   GString *data_str;
   gsize data_length;
   char *lang;
   GList *l;
 
-  snapshot_service = ephy_snapshot_service_get_default ();
-  shell = ephy_embed_shell_get_default ();
-
   data_str = g_string_new (NULL);
 
   lang = g_strdup (pango_language_to_string (gtk_get_default_language ()));
@@ -461,7 +374,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
     GtkIconInfo *icon_info;
 
     icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                            "web-browser-symbolic",
+                                            "org.gnome.Epiphany-symbolic",
                                             128,
                                             0);
     g_string_append_printf (data_str,
@@ -488,10 +401,18 @@ history_service_query_urls_cb (EphyHistoryService     *history,
     char *thumbnail_style = NULL;
 
     snapshot = ephy_snapshot_service_lookup_cached_snapshot_path (snapshot_service, url->url);
-    if (snapshot)
+    if (!snapshot) {
+      GetSnapshotPathAsyncData *data = g_new (GetSnapshotPathAsyncData, 1);
+
+      data->url = g_strdup (url->url);
+      data->mtime = url->thumbnail_time;
+      ephy_snapshot_service_get_snapshot_path_for_url_async (ephy_snapshot_service_get_default (),
+                                                             url->url, url->thumbnail_time, NULL,
+                                                             (GAsyncReadyCallback)got_snapshot_path_for_url_cb,
+                                                             data);
+    } else {
       thumbnail_style = g_strdup_printf (" style=\"background: url(file://%s) no-repeat;\"", snapshot);
-    else
-      ephy_embed_shell_schedule_thumbnail_update (shell, url);
+    }
 
     g_string_append_printf (data_str,
                             "<a class=\"overview-item\" title=\"%s\" href=\"%s\">"
@@ -514,20 +435,6 @@ history_service_query_urls_cb (EphyHistoryService     *history,
   g_object_unref (request);
 }
 
-EphyHistoryQuery *
-ephy_history_query_new_for_overview (void)
-{
-  EphyHistoryQuery *query;
-
-  query = ephy_history_query_new ();
-  query->sort_type = EPHY_HISTORY_SORT_MOST_VISITED;
-  query->limit = EPHY_ABOUT_OVERVIEW_MAX_ITEMS;
-  query->ignore_hidden = TRUE;
-  query->ignore_local = TRUE;
-
-  return query;
-}
-
 static gboolean
 ephy_about_handler_handle_html_overview (EphyAboutHandler       *handler,
                                          WebKitURISchemeRequest *request)
@@ -536,7 +443,11 @@ ephy_about_handler_handle_html_overview (EphyAboutHandler       *handler,
   EphyHistoryQuery *query;
 
   history = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ()));
-  query = ephy_history_query_new_for_overview ();
+  query = ephy_history_query_new ();
+  query->sort_type = EPHY_HISTORY_SORT_MOST_VISITED;
+  query->limit = EPHY_ABOUT_OVERVIEW_MAX_ITEMS;
+  query->ignore_hidden = TRUE;
+  query->ignore_local = TRUE;
   ephy_history_service_query_urls (history, query, NULL,
                                    (EphyHistoryJobCallback)history_service_query_urls_cb,
                                    g_object_ref (request));
@@ -613,9 +524,7 @@ ephy_about_handler_handle_request (EphyAboutHandler       *handler,
 
   path = webkit_uri_scheme_request_get_path (request);
 
-  if (!g_strcmp0 (path, "plugins"))
-    handled = ephy_about_handler_handle_plugins (handler, request);
-  else if (!g_strcmp0 (path, "memory"))
+  if (!g_strcmp0 (path, "memory"))
     handled = ephy_about_handler_handle_memory (handler, request);
   else if (!g_strcmp0 (path, "epiphany"))
     handled = ephy_about_handler_handle_epiphany (handler, request);
