@@ -2,22 +2,23 @@
 /*
  *  Copyright © 2012, 2013 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_ABOUT_HANDLER_H
-#define EPHY_ABOUT_HANDLER_H
+#pragma once
 
 #include <webkit2/webkit2.h>
 
@@ -29,11 +30,9 @@ G_DECLARE_FINAL_TYPE (EphyAboutHandler, ephy_about_handler, EPHY, ABOUT_HANDLER,
 
 #define EPHY_ABOUT_SCHEME "ephy-about"
 #define EPHY_ABOUT_SCHEME_LEN 10
-#define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 10
+#define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 9
 
 EphyAboutHandler *ephy_about_handler_new            (void);
 void              ephy_about_handler_handle_request (EphyAboutHandler       *handler,
                                                      WebKitURISchemeRequest *request);
 G_END_DECLS
-
-#endif /* EPHY_ABOUT_HANDLER_H */
