@@ -3,18 +3,20 @@
  *  Copyright © 2000-2003 Marco Pesenti Gritti
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -33,9 +35,10 @@
 #include "ephy-profile-utils.h"
 #include "ephy-settings.h"
 #include "ephy-snapshot-service.h"
+#include "ephy-uri-tester.h"
+#include "ephy-view-source-handler.h"
 #include "ephy-web-app-utils.h"
 #include "ephy-web-extension-proxy.h"
-#include "ephy-web-extension-names.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -56,8 +59,10 @@ typedef struct {
   EphyDownloadsManager *downloads_manager;
   EphyHostsManager *hosts_manager;
   EphyAboutHandler *about_handler;
+  EphyViewSourceHandler *source_handler;
   guint update_overview_timeout_id;
   guint hiding_overview_item;
+  EphyUriTester *uri_tester;
   GDBusServer *dbus_server;
   GList *web_extensions;
 } EphyEmbedShellPrivate;
@@ -101,10 +106,12 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->print_settings);
   g_clear_object (&priv->global_history_service);
   g_clear_object (&priv->about_handler);
+  g_clear_object (&priv->source_handler);
   g_clear_object (&priv->user_content);
   g_clear_object (&priv->downloads_manager);
   g_clear_object (&priv->hosts_manager);
   g_clear_object (&priv->web_context);
+  g_clear_object (&priv->uri_tester);
   g_clear_object (&priv->dbus_server);
 
   G_OBJECT_CLASS (ephy_embed_shell_parent_class)->dispose (object);
@@ -149,9 +156,6 @@ history_service_query_urls_cb (EphyHistoryService *service,
 
     ephy_web_extension_proxy_history_set_urls (web_extension, urls);
   }
-
-  for (l = urls; l; l = g_list_next (l))
-    ephy_embed_shell_schedule_thumbnail_update (shell, (EphyHistoryURL *)l->data);
 }
 
 static void
@@ -160,7 +164,12 @@ ephy_embed_shell_update_overview_urls (EphyEmbedShell *shell)
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   EphyHistoryQuery *query;
 
-  query = ephy_history_query_new_for_overview ();
+  query = ephy_history_query_new ();
+  query->sort_type = EPHY_HISTORY_SORT_MOST_VISITED;
+  query->limit = EPHY_ABOUT_OVERVIEW_MAX_ITEMS;
+  query->ignore_hidden = TRUE;
+  query->ignore_local = TRUE;
+
   ephy_history_service_query_urls (priv->global_history_service, query, NULL,
                                    (EphyHistoryJobCallback)history_service_query_urls_cb,
                                    shell);
@@ -343,8 +352,7 @@ delayed_thumbnail_update_data_new (EphyWebExtensionProxy *extension,
 static void
 delayed_thumbnail_update_data_free (DelayedThumbnailUpdateData *data)
 {
-  if (data->extension)
-    g_object_remove_weak_pointer (G_OBJECT (data->extension), (gpointer *)&data->extension);
+  g_object_remove_weak_pointer (G_OBJECT (data->extension), (gpointer *)&data->extension);
   g_free (data->url);
   g_free (data->path);
   g_free (data);
@@ -388,56 +396,6 @@ ephy_embed_shell_set_thumbnail_path (EphyEmbedShell *shell,
   }
 }
 
-typedef struct {
-  char *url;
-  time_t mtime;
-} GetSnapshotPathAsyncData;
-
-static void
-got_snapshot_path_for_url_cb (EphySnapshotService      *service,
-                              GAsyncResult             *result,
-                              GetSnapshotPathAsyncData *data)
-{
-  char *snapshot;
-  GError *error = NULL;
-
-  snapshot = ephy_snapshot_service_get_snapshot_path_for_url_finish (service, result, &error);
-  if (snapshot) {
-    ephy_embed_shell_set_thumbnail_path (ephy_embed_shell_get_default (), data->url, data->mtime, snapshot);
-    g_free (snapshot);
-  } else {
-    /* Bad luck, not something to warn about. */
-    g_info ("Failed to get snapshot for URL %s: %s", data->url, error->message);
-    g_error_free (error);
-  }
-  g_free (data->url);
-  g_free (data);
-}
-
-void
-ephy_embed_shell_schedule_thumbnail_update (EphyEmbedShell *shell,
-                                            EphyHistoryURL *url)
-{
-  EphySnapshotService *service;
-  const char *snapshot;
-
-  service = ephy_snapshot_service_get_default ();
-  snapshot = ephy_snapshot_service_lookup_cached_snapshot_path (service, url->url);
-
-  if (snapshot) {
-    ephy_embed_shell_set_thumbnail_path (shell, url->url, url->thumbnail_time, snapshot);
-  } else {
-    GetSnapshotPathAsyncData *data = g_new (GetSnapshotPathAsyncData, 1);
-
-    data->url = g_strdup (url->url);
-    data->mtime = url->thumbnail_time;
-    ephy_snapshot_service_get_snapshot_path_for_url_async (service,
-                                                           url->url, url->thumbnail_time, NULL,
-                                                           (GAsyncReadyCallback)got_snapshot_path_for_url_cb,
-                                                           data);
-  }
-}
-
 /**
  * ephy_embed_shell_get_global_history_service:
  * @shell: the #EphyEmbedShell
@@ -453,16 +411,10 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
 
   if (priv->global_history_service == NULL) {
     char *filename;
-    EphySQLiteConnectionMode mode;
-
-    if (priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO ||
-        priv->mode == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER)
-      mode = EPHY_SQLITE_CONNECTION_MODE_READ_ONLY;
-    else
-      mode = EPHY_SQLITE_CONNECTION_MODE_READWRITE;
 
     filename = g_build_filename (ephy_dot_dir (), EPHY_HISTORY_FILE, NULL);
-    priv->global_history_service = ephy_history_service_new (filename, mode);
+    priv->global_history_service = ephy_history_service_new (filename,
+                                                             priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO);
     g_free (filename);
     g_return_val_if_fail (priv->global_history_service, NULL);
     g_signal_connect (priv->global_history_service, "urls-visited",
@@ -530,6 +482,15 @@ about_request_cb (WebKitURISchemeRequest *request,
   ephy_about_handler_handle_request (priv->about_handler, request);
 }
 
+static void
+source_request_cb (WebKitURISchemeRequest *request,
+                   EphyEmbedShell         *shell)
+{
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
+
+  ephy_view_source_handler_handle_request (priv->source_handler, request);
+}
+
 static void
 ephy_resource_request_cb (WebKitURISchemeRequest *request)
 {
@@ -646,9 +607,12 @@ new_connection_cb (GDBusServer     *server,
                    GDBusConnection *connection,
                    EphyEmbedShell  *shell)
 {
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   EphyWebExtensionProxy *extension = ephy_web_extension_proxy_new (connection);
   ephy_embed_shell_watch_web_extension (shell, extension);
 
+  ephy_uri_tester_register_dbus_object (priv->uri_tester, connection);
+
   g_signal_connect_object (extension, "page-created",
                            G_CALLBACK (web_extension_page_created), shell, 0);
 
@@ -835,6 +799,12 @@ ephy_embed_shell_startup (GApplication *application)
   webkit_security_manager_register_uri_scheme_as_local (webkit_web_context_get_security_manager (priv->web_context),
                                                         EPHY_ABOUT_SCHEME);
 
+  /* view source handler */
+  priv->source_handler = ephy_view_source_handler_new ();
+  webkit_web_context_register_uri_scheme (priv->web_context, EPHY_VIEW_SOURCE_SCHEME,
+                                          (WebKitURISchemeRequestCallback)source_request_cb,
+                                          shell, NULL);
+
   /* ephy-resource handler */
   webkit_web_context_register_uri_scheme (priv->web_context, "ephy-resource",
                                           (WebKitURISchemeRequestCallback)ephy_resource_request_cb,
@@ -918,19 +888,25 @@ ephy_embed_shell_constructed (GObject *object)
 {
   EphyEmbedShell *shell;
   EphyEmbedShellPrivate *priv;
+  EphyEmbedShellMode mode;
 
   G_OBJECT_CLASS (ephy_embed_shell_parent_class)->constructed (object);
 
   shell = EPHY_EMBED_SHELL (object);
   priv = ephy_embed_shell_get_instance_private (shell);
+  mode = ephy_embed_shell_get_mode (shell);
+
   /* These do not run the EmbedShell application instance, so make sure that
      there is a web context and a user content manager for them. */
-  if (ephy_embed_shell_get_mode (shell) == EPHY_EMBED_SHELL_MODE_TEST ||
-      ephy_embed_shell_get_mode (shell) == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
+  if (mode == EPHY_EMBED_SHELL_MODE_TEST ||
+      mode == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
     ephy_embed_shell_create_web_context (shell);
     priv->user_content = webkit_user_content_manager_new ();
   }
 
+  if (mode != EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER)
+    priv->uri_tester = ephy_uri_tester_new ();
+
   g_signal_connect_object (ephy_snapshot_service_get_default (),
                            "snapshot-saved", G_CALLBACK (snapshot_saved_cb),
                            shell, 0);
