@@ -29,6 +29,7 @@
 
 #include "ephy-dbus-names.h"
 #include "ephy-debug.h"
+#include "ephy-embed-shell.h"
 #include "ephy-file-helpers.h"
 #include "ephy-settings.h"
 #include "ephy-uri-helpers.h"
@@ -977,7 +978,6 @@ handle_deferred_request (DeferredRequest *request,
                                    request->invocation);
 }
 
-#if 0
 static void
 https_everywhere_update_cb (HTTPSEverywhereUpdater *updater,
                             GAsyncResult *result)
@@ -995,16 +995,19 @@ https_everywhere_update_cb (HTTPSEverywhereUpdater *updater,
 
   g_object_unref (updater);
 }
-#endif
 
 static void
 ephy_uri_tester_update_https_everywhere_rulesets (EphyUriTester *tester)
 {
-#if 0
-  // Temporarily disabled because the lock file is not getting removed properly
-  // during tests, causing test failures.
-
   HTTPSEverywhereUpdater *updater;
+  EphyEmbedShell *shell;
+  EphyEmbedShellMode mode;
+
+  shell = ephy_embed_shell_get_default ();
+  mode = ephy_embed_shell_get_mode (shell);
+
+  if (mode == EPHY_EMBED_SHELL_MODE_TEST || mode == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER)
+    return;
 
   /* We might want to be smarter about this in the future. For now,
    * trigger an update of the rulesets once each time an EphyUriTester
@@ -1017,7 +1020,6 @@ ephy_uri_tester_update_https_everywhere_rulesets (EphyUriTester *tester)
                                    tester->cancellable,
                                    (GAsyncReadyCallback)https_everywhere_update_cb,
                                    NULL);
-#endif
 }
 
 static void
