@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  *  Copyright © 2013 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -41,6 +42,7 @@ ephy_web_dom_utils_has_modified_forms (WebKitDOMDocument *document)
   WebKitDOMHTMLCollection *forms;
   gulong forms_n;
   guint i;
+  gboolean modified_forms = FALSE;
 
   forms = webkit_dom_document_get_forms (document);
   forms_n = webkit_dom_html_collection_get_length (forms);
@@ -69,8 +71,11 @@ ephy_web_dom_utils_has_modified_forms (WebKitDOMDocument *document)
           has_data = text && *text;
           g_free (text);
 
-          if (has_data)
-            return TRUE;
+          if (has_data) {
+            g_object_unref (elements);
+            modified_forms = TRUE;
+            goto out;
+          }
         }
 
       if (WEBKIT_DOM_IS_HTML_INPUT_ELEMENT (element))
@@ -82,8 +87,11 @@ ephy_web_dom_utils_has_modified_forms (WebKitDOMDocument *document)
            * modified and it does not have a lot of text the user is
            * likely not very interested in saving this work, so do
            * nothing (eg, google search input). */
-          if (modified_input_element)
-            return TRUE;
+          if (modified_input_element) {
+            g_object_unref (elements);
+            modified_forms = TRUE;
+            goto out;
+          }
 
           modified_input_element = TRUE;
 
@@ -91,13 +99,19 @@ ephy_web_dom_utils_has_modified_forms (WebKitDOMDocument *document)
           length = g_utf8_strlen (text, -1);
           g_free (text);
 
-          if (length > 50)
-            return TRUE;
+          if (length > 50) {
+            g_object_unref (elements);
+            modified_forms = TRUE;
+            goto out;
+          }
         }
     }
+    g_object_unref (elements);
   }
 
-  return FALSE;
+ out:
+  g_object_unref (forms);
+  return modified_forms;
 }
 
 /**
@@ -110,17 +124,17 @@ ephy_web_dom_utils_has_modified_forms (WebKitDOMDocument *document)
 char *
 ephy_web_dom_utils_get_application_title (WebKitDOMDocument *document)
 {
-  WebKitDOMNodeList *metas;
+  WebKitDOMHTMLCollection *metas;
   char *title = NULL;
   gulong length, i;
 
-  metas = webkit_dom_document_get_elements_by_tag_name (document, "meta");
-  length = webkit_dom_node_list_get_length (metas);
+  metas = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "meta");
+  length = webkit_dom_html_collection_get_length (metas);
 
   for (i = 0; i < length && title == NULL; i++) {
     char *name;
     char *property;
-    WebKitDOMNode *node = webkit_dom_node_list_item (metas, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (metas, i);
 
     /* og:site_name is read from the property attribute (standard), but is
      * commonly seen on the web in the name attribute. Both are supported. */
@@ -138,6 +152,7 @@ ephy_web_dom_utils_get_application_title (WebKitDOMDocument *document)
     g_free (property);
     g_free (name);
   }
+  g_object_unref (metas);
 
   return title;
 }
@@ -170,17 +185,17 @@ get_icon_from_html_icon (WebKitDOMDocument *document,
                          char             **uri_out)
 {
   gboolean ret;
-  WebKitDOMNodeList *links;
+  WebKitDOMHTMLCollection *links;
   gulong length, i;
   char *image = NULL;
   int largest_icon = 0;
 
-  links = webkit_dom_document_get_elements_by_tag_name (document, "link");
-  length = webkit_dom_node_list_get_length (links);
+  links = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "link");
+  length = webkit_dom_html_collection_get_length (links);
 
   for (i = 0; i < length; i++) {
     char *rel;
-    WebKitDOMNode *node = webkit_dom_node_list_item (links, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (links, i);
 
     rel = webkit_dom_html_link_element_get_rel (WEBKIT_DOM_HTML_LINK_ELEMENT (node));
     if (rel != NULL && (
@@ -226,6 +241,7 @@ get_icon_from_html_icon (WebKitDOMDocument *document,
     else
       g_free (rel);
   }
+  g_object_unref (links);
 
   ret = (image != NULL && *image != '\0');
 
@@ -241,19 +257,19 @@ get_icon_from_mstile (WebKitDOMDocument *document,
                       char             **color_out)
 {
   gboolean ret;
-  WebKitDOMNodeList *metas;
+  WebKitDOMHTMLCollection *metas;
   gulong length, i;
   char *image = NULL;
   char *color = NULL;
 
-  metas = webkit_dom_document_get_elements_by_tag_name (document, "meta");
-  length = webkit_dom_node_list_get_length (metas);
+  metas = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "meta");
+  length = webkit_dom_html_collection_get_length (metas);
 
   /* FIXME: Ought to also search browserconfig.xml
    * See: http://stackoverflow.com/questions/24625305/msapplication-tileimage-favicon-backup
    */
   for (i = 0; i < length; i++) {
-    WebKitDOMNode *node = webkit_dom_node_list_item (metas, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (metas, i);
     char *name;
 
     name = webkit_dom_html_meta_element_get_name (WEBKIT_DOM_HTML_META_ELEMENT (node));
@@ -268,6 +284,7 @@ get_icon_from_mstile (WebKitDOMDocument *document,
       }
     }
   }
+  g_object_unref (metas);
 
   ret = (image != NULL && *image != '\0');
 
@@ -284,15 +301,15 @@ get_icon_from_ogp (WebKitDOMDocument *document,
                    char             **uri_out)
 {
   gboolean ret;
-  WebKitDOMNodeList *metas;
+  WebKitDOMHTMLCollection *metas;
   gulong length, i;
   char *image = NULL;
 
-  metas = webkit_dom_document_get_elements_by_tag_name (document, "meta");
-  length = webkit_dom_node_list_get_length (metas);
+  metas = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "meta");
+  length = webkit_dom_html_collection_get_length (metas);
 
   for (i = 0; i < length && image == NULL; i++) {
-    WebKitDOMNode *node = webkit_dom_node_list_item (metas, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (metas, i);
     char *property;
     char *itemprop;
 
@@ -306,6 +323,7 @@ get_icon_from_ogp (WebKitDOMDocument *document,
     g_free (property);
     g_free (itemprop);
   }
+  g_object_unref (metas);
 
   ret = (image != NULL && *image != '\0');
 
@@ -320,16 +338,16 @@ get_icon_from_touch_icon (WebKitDOMDocument *document,
                           char             **uri_out)
 {
   gboolean ret;
-  WebKitDOMNodeList *links;
+  WebKitDOMHTMLCollection *links;
   gulong length, i;
   char *image = NULL;
 
-  links = webkit_dom_document_get_elements_by_tag_name (document, "link");
-  length = webkit_dom_node_list_get_length (links);
+  links = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "link");
+  length = webkit_dom_html_collection_get_length (links);
 
   for (i = 0; i < length && image == NULL; i++) {
     char *rel;
-    WebKitDOMNode *node = webkit_dom_node_list_item (links, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (links, i);
 
     rel = webkit_dom_html_link_element_get_rel (WEBKIT_DOM_HTML_LINK_ELEMENT (node));
     /* TODO: support more than one possible icon. */
@@ -345,6 +363,7 @@ get_icon_from_touch_icon (WebKitDOMDocument *document,
     }
     g_free (rel);
   }
+  g_object_unref (links);
 
   /* TODO: Try to retrieve /apple-touch-icon.png, and return it if it exist. */
 
@@ -360,16 +379,16 @@ static void
 get_icon_from_favicon (WebKitDOMDocument *document,
                        char             **uri_out)
 {
-  WebKitDOMNodeList *links;
+  WebKitDOMHTMLCollection *links;
   gulong length, i;
   char *image = NULL;
 
-  links = webkit_dom_document_get_elements_by_tag_name (document, "link");
-  length = webkit_dom_node_list_get_length (links);
+  links = webkit_dom_document_get_elements_by_tag_name_as_html_collection (document, "link");
+  length = webkit_dom_html_collection_get_length (links);
 
   for (i = 0; i < length; i++) {
     char *rel;
-    WebKitDOMNode *node = webkit_dom_node_list_item (links, i);
+    WebKitDOMNode *node = webkit_dom_html_collection_item (links, i);
 
     rel = webkit_dom_html_link_element_get_rel (WEBKIT_DOM_HTML_LINK_ELEMENT (node));
     if (rel != NULL && (
@@ -382,6 +401,7 @@ get_icon_from_favicon (WebKitDOMDocument *document,
     }
     g_free (rel);
   }
+  g_object_unref (links);
 
   /* Last ditch effort: just fallback to the default favicon location. */
   if (image == NULL)
@@ -416,6 +436,8 @@ ephy_web_dom_utils_get_best_icon (WebKitDOMDocument *document,
 
   /* FIXME: These functions could be improved considerably. See the first two answers at:
    * http://stackoverflow.com/questions/21991044/how-to-get-high-resolution-website-logo-favicon-for-a-given-url
+   *
+   * Also check out: https://www.slightfuture.com/webdev/gnome-web-app-icons
    */
   found_icon = get_icon_from_html_icon (document, &image);
   if (!found_icon)
