@@ -1,59 +1,60 @@
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2002 Jorn Baayen
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2004, 2005, 2006 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_FILE_HELPERS_H
-#define EPHY_FILE_HELPERS_H
+#pragma once
 
 #include <glib.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
 extern GQuark ephy_file_helpers_error_quark;
-#define EPHY_FILE_HELPERS_ERROR_QUARK	(ephy_file_helpers_error_quark)
+#define EPHY_FILE_HELPERS_ERROR_QUARK        (ephy_file_helpers_error_quark)
 
 G_BEGIN_DECLS
 
 typedef enum
 {
-	EPHY_MIME_PERMISSION_SAFE	= 1,
-	EPHY_MIME_PERMISSION_UNSAFE	= 2,
-	EPHY_MIME_PERMISSION_UNKNOWN	= 3
+  EPHY_MIME_PERMISSION_SAFE    = 1,
+  EPHY_MIME_PERMISSION_UNSAFE  = 2,
+  EPHY_MIME_PERMISSION_UNKNOWN = 3
 } EphyMimePermission;
 
 typedef enum
 {
-	EPHY_FILE_HELPERS_NONE		   = 0,
-	EPHY_FILE_HELPERS_KEEP_DIR	   = 1 << 1,
-	EPHY_FILE_HELPERS_PRIVATE_PROFILE  = 1 << 2,
-	EPHY_FILE_HELPERS_ENSURE_EXISTS	   = 1 << 3,
-	EPHY_FILE_HELPERS_STEAL_DATA       = 1 << 4
+  EPHY_FILE_HELPERS_NONE             = 0,
+  EPHY_FILE_HELPERS_KEEP_DIR         = 1 << 1,
+  EPHY_FILE_HELPERS_PRIVATE_PROFILE  = 1 << 2,
+  EPHY_FILE_HELPERS_ENSURE_EXISTS    = 1 << 3,
+  EPHY_FILE_HELPERS_STEAL_DATA       = 1 << 4
 } EphyFileHelpersFlags;
 
 gboolean           ephy_file_helpers_init                   (const char            *profile_dir,
                                                              EphyFileHelpersFlags   flags,
                                                              GError               **error);
-const char *       ephy_file                                (const char            *filename);
 const char *       ephy_dot_dir                             (void);
 gboolean           ephy_dot_dir_is_default                  (void);
 char       *       ephy_default_dot_dir                     (void);
 void               ephy_file_helpers_shutdown               (void);
-char	   *          ephy_file_get_downloads_dir              (void);
+char       *       ephy_file_get_downloads_dir              (void);
 char       *       ephy_file_desktop_dir                    (void);
 const char *       ephy_file_tmp_dir                        (void);
 char       *       ephy_file_tmp_filename                   (const char            *base,
@@ -94,5 +95,3 @@ GAppInfo   *       ephy_file_launcher_get_app_info_for_file (GFile
 void               ephy_open_incognito_window               (const char *uri);
 
 G_END_DECLS
-
-#endif /* EPHY_FILE_HELPERS_H */
