@@ -1,19 +1,22 @@
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2003 Marco Pesenti Gritti
  *  Copyright © 2003, 2004 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -45,24 +48,17 @@ ephy_file_chooser_init (EphyFileChooser *dialog)
 {
 }
 
-static GObject *
-ephy_file_chooser_constructor (GType                  type,
-                               guint                  n_construct_properties,
-                               GObjectConstructParam *construct_params)
+static void
+ephy_file_chooser_constructed (GObject *object)
 
 {
-  GObject *object;
   char *downloads_dir;
 
-  object = G_OBJECT_CLASS (ephy_file_chooser_parent_class)->constructor (type, n_construct_properties,
-                                                                         construct_params);
+  G_OBJECT_CLASS (ephy_file_chooser_parent_class)->constructed (object);
 
   downloads_dir = ephy_file_get_downloads_dir ();
-  gtk_file_chooser_add_shortcut_folder
-    (GTK_FILE_CHOOSER (object), downloads_dir, NULL);
+  gtk_file_chooser_add_shortcut_folder (GTK_FILE_CHOOSER (object), downloads_dir, NULL);
   g_free (downloads_dir);
-
-  return object;
 }
 
 GtkFileFilter *
@@ -126,7 +122,7 @@ ephy_file_chooser_class_init (EphyFileChooserClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  object_class->constructor = ephy_file_chooser_constructor;
+  object_class->constructed = ephy_file_chooser_constructed;
 }
 
 static void
