@@ -4,25 +4,26 @@
  *  Copyright © 2006, 2008 Christian Persch
  *  Copyright © 2011, 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
-#include "ephy-initial-state.h"
 #include "ephy-private.h"
 #include "ephy-profile-utils.h"
 #include "ephy-session.h"
@@ -35,12 +36,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libnotify/notify.h>
+#include <libxml/xmlreader.h>
 #include <libxml/xmlversion.h>
 #include <string.h>
-
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
+#include <stdlib.h>
 
 static gboolean open_in_new_tab = FALSE;
 static gboolean open_in_new_window = FALSE;
@@ -80,6 +79,7 @@ option_version_cb (const gchar *option_name,
   return FALSE;
 }
 
+/* If you're modifying this array then you need to update the manpage. */
 static const GOptionEntry option_entries[] =
 {
   { "new-tab", 'n', 0, G_OPTION_ARG_NONE, &open_in_new_tab,
@@ -96,8 +96,6 @@ static const GOptionEntry option_entries[] =
     N_("Start a private instance"), NULL },
   { "incognito-mode", 'i', 0, G_OPTION_ARG_NONE, &incognito_mode,
     N_("Start an instance in incognito mode"), NULL },
-  { "netbank-mode", 0, 0, G_OPTION_ARG_NONE, &incognito_mode,
-    N_("Start an instance in netbank mode"), NULL },
   { "application-mode", 'a', G_OPTION_FLAG_FILENAME | G_OPTION_FLAG_OPTIONAL_ARG,
     G_OPTION_ARG_CALLBACK, application_mode_cb,
     N_("Start the browser in application mode"), NULL },
@@ -120,7 +118,8 @@ get_startup_id (void)
   guint32 retval = 0;
 
   startup_id = g_getenv ("DESKTOP_STARTUP_ID");
-  if (startup_id == NULL) return 0;
+  if (startup_id == NULL)
+    return 0;
 
   /* Find the launch time from the startup_id, if it's there.  Newer spec
    * states that the startup_id is of the form <unique>_TIME<timestamp>
@@ -142,63 +141,6 @@ get_startup_id (void)
   return retval;
 }
 
-#ifdef GDK_WINDOWING_X11
-/*
- * FIXME: Need a solution for windowing-systems other than X11.
- */
-
-/* Copied from libnautilus/nautilus-program-choosing.c; Needed in case
- * we have no DESKTOP_STARTUP_ID (with its accompanying timestamp).
- */
-static Time
-slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
-{
-  Window xwindow;
-  XEvent event;
-
-  {
-    XSetWindowAttributes attrs;
-    Atom atom_name;
-    Atom atom_type;
-    const char *name;
-
-    attrs.override_redirect = True;
-    attrs.event_mask = PropertyChangeMask | StructureNotifyMask;
-
-    xwindow =
-      XCreateWindow (xdisplay,
-                     RootWindow (xdisplay, 0),
-                     -100, -100, 1, 1,
-                     0,
-                     CopyFromParent,
-                     CopyFromParent,
-                     CopyFromParent,
-                     CWOverrideRedirect | CWEventMask,
-                     &attrs);
-
-    atom_name = XInternAtom (xdisplay, "WM_NAME", TRUE);
-    g_assert (atom_name != None);
-    atom_type = XInternAtom (xdisplay, "STRING", TRUE);
-    g_assert (atom_type != None);
-
-    name = "Fake Window";
-    XChangeProperty (xdisplay,
-                     xwindow, atom_name,
-                     atom_type,
-                     8, PropModeReplace, (unsigned char *)name, strlen (name));
-  }
-
-  XWindowEvent (xdisplay,
-                xwindow,
-                PropertyChangeMask,
-                &event);
-
-  XDestroyWindow (xdisplay, xwindow);
-
-  return event.xproperty.time;
-}
-#endif
-
 static void
 show_error_message (GError **error)
 {
@@ -429,17 +371,6 @@ main (int   argc,
     arguments = args;
   }
 
-#ifdef GDK_WINDOWING_X11
-  /* Get a timestamp manually if need be */
-  if (user_time == 0) {
-    GdkDisplay *display =
-      gdk_display_manager_get_default_display (gdk_display_manager_get ());
-    if (GDK_IS_X11_DISPLAY (display))
-      user_time =
-        slowly_and_stupidly_obtain_timestamp (GDK_DISPLAY_XDISPLAY (display));
-  }
-#endif
-
   /* Delete the requested web application, if any. Must happen after
    * ephy_file_helpers_init (). */
   if (application_to_delete) {
@@ -478,7 +409,7 @@ main (int   argc,
     g_set_prgname ("epiphany");
     g_set_application_name (_("Web"));
 
-    gtk_window_set_default_icon_name ("web-browser");
+    gtk_window_set_default_icon_name ("org.gnome.Epiphany");
   }
 
   _ephy_shell_create_instance (mode);
@@ -503,7 +434,6 @@ main (int   argc,
   if (notify_is_initted ())
     notify_uninit ();
 
-  ephy_initial_state_save ();
   ephy_settings_shutdown ();
   ephy_file_helpers_shutdown ();
   xmlCleanupParser ();
