@@ -1,21 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2002 Christophe Fergeau
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004, 2005 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -38,7 +40,6 @@
 #define TAB_WIDTH_N_CHARS 15
 
 #define AFTER_ALL_TABS -1
-#define NOT_IN_APP_WINDOWS -2
 
 #define INSANE_NUMBER_OF_URLS 20
 
@@ -156,50 +157,6 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
   g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
 }
 
-
-/* FIXME remove when gtknotebook's func for this becomes public, bug #.... */
-static EphyNotebook *
-find_notebook_at_pointer (GdkDisplay *display, gint abs_x, gint abs_y)
-{
-  GdkWindow *win_at_pointer, *toplevel_win;
-  gpointer toplevel = NULL;
-  gint x, y;
-
-  win_at_pointer = gdk_device_get_window_at_position (
-    gdk_device_manager_get_client_pointer (
-      gdk_display_get_device_manager (display)),
-    &x, &y);
-  if (win_at_pointer == NULL) {
-    /* We are outside all windows containing a notebook */
-    return NULL;
-  }
-
-  toplevel_win = gdk_window_get_toplevel (win_at_pointer);
-
-  /* get the GtkWidget which owns the toplevel GdkWindow */
-  gdk_window_get_user_data (toplevel_win, &toplevel);
-
-  /* toplevel should be an EphyWindow */
-  if (toplevel != NULL && EPHY_IS_WINDOW (toplevel)) {
-    return EPHY_NOTEBOOK (ephy_window_get_notebook
-                            (EPHY_WINDOW (toplevel)));
-  }
-
-  return NULL;
-}
-
-static gboolean
-is_in_notebook_window (EphyNotebook *notebook,
-                       gint abs_x, gint abs_y)
-{
-  EphyNotebook *nb_at_pointer;
-
-  nb_at_pointer = find_notebook_at_pointer (gtk_widget_get_display (GTK_WIDGET (notebook)),
-                                            abs_x, abs_y);
-
-  return nb_at_pointer == notebook;
-}
-
 static gint
 find_tab_num_at_pos (EphyNotebook *notebook, gint abs_x, gint abs_y)
 {
@@ -207,12 +164,6 @@ find_tab_num_at_pos (EphyNotebook *notebook, gint abs_x, gint abs_y)
   GtkNotebook *nb = GTK_NOTEBOOK (notebook);
   GtkWidget *page;
 
-  /* For some reason unfullscreen + quick click can
-     cause a wrong click event to be reported to the tab */
-  if (!is_in_notebook_window (notebook, abs_x, abs_y)) {
-    return NOT_IN_APP_WINDOWS;
-  }
-
   while ((page = gtk_notebook_get_nth_page (nb, page_num))) {
     GtkWidget *tab;
     GtkAllocation allocation;
@@ -390,6 +341,59 @@ update_tabs_visibility (EphyNotebook *nb,
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), nb->tabs_allowed && show_tabs);
 }
 
+static void
+expand_tabs_changed_cb (GSettings    *settings,
+                        char         *key,
+                        EphyNotebook *nb)
+{
+  GList *tabs;
+  GList *l;
+  gboolean expand;
+
+  expand = g_settings_get_boolean (EPHY_SETTINGS_UI,
+                                   EPHY_PREFS_UI_EXPAND_TABS_BAR),
+
+  tabs = gtk_container_get_children (GTK_CONTAINER (nb));
+
+  for (l = tabs; l != NULL; l = l->next) {
+    gtk_container_child_set (GTK_CONTAINER (nb),
+                             l->data,
+                             "tab-expand", expand,
+                             NULL);
+  }
+
+  g_list_free (tabs);
+}
+
+static GtkPositionType
+ephy_settings_get_tabs_bar_position (void)
+{
+  EphyPrefsUITabsBarPosition position;
+  position = g_settings_get_enum (EPHY_SETTINGS_UI,
+                                  EPHY_PREFS_UI_TABS_BAR_POSITION);
+
+  switch (position) {
+    case EPHY_PREFS_UI_TABS_BAR_POSITION_TOP:
+      return GTK_POS_TOP;
+    case EPHY_PREFS_UI_TABS_BAR_POSITION_BOTTOM:
+      return GTK_POS_BOTTOM;
+    case EPHY_PREFS_UI_TABS_BAR_POSITION_LEFT:
+      return GTK_POS_LEFT;
+    case EPHY_PREFS_UI_TABS_BAR_POSITION_RIGHT:
+      return GTK_POS_RIGHT;
+    default:
+      g_assert_not_reached ();
+  }
+}
+
+static void
+position_changed_cb (GSettings    *settings,
+                     char         *key,
+                     EphyNotebook *nb)
+{
+  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (nb), ephy_settings_get_tabs_bar_position ());
+}
+
 static void
 show_tabs_changed_cb (GSettings    *settings,
                       char         *key,
@@ -408,6 +412,7 @@ ephy_notebook_init (EphyNotebook *notebook)
   gtk_notebook_set_show_border (gnotebook, FALSE);
   gtk_notebook_set_show_tabs (gnotebook, FALSE);
   gtk_notebook_set_group_name (gnotebook, EPHY_NOTEBOOK_TAB_GROUP_ID);
+  gtk_notebook_set_tab_pos (gnotebook, ephy_settings_get_tabs_bar_position ());
 
   notebook->tabs_allowed = TRUE;
 
@@ -426,6 +431,12 @@ ephy_notebook_init (EphyNotebook *notebook)
                      GDK_ACTION_MOVE | GDK_ACTION_COPY);
   gtk_drag_dest_add_text_targets (widget);
 
+  g_signal_connect (EPHY_SETTINGS_UI,
+                    "changed::" EPHY_PREFS_UI_EXPAND_TABS_BAR,
+                    G_CALLBACK (expand_tabs_changed_cb), notebook);
+  g_signal_connect (EPHY_SETTINGS_UI,
+                    "changed::" EPHY_PREFS_UI_TABS_BAR_POSITION,
+                    G_CALLBACK (position_changed_cb), notebook);
   g_signal_connect (EPHY_SETTINGS_UI,
                     "changed::" EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY,
                     G_CALLBACK (show_tabs_changed_cb), notebook);
@@ -436,9 +447,16 @@ ephy_notebook_finalize (GObject *object)
 {
   EphyNotebook *notebook = EPHY_NOTEBOOK (object);
 
+  g_signal_handlers_disconnect_by_func (EPHY_SETTINGS_UI,
+                                        expand_tabs_changed_cb,
+                                        notebook);
+  g_signal_handlers_disconnect_by_func (EPHY_SETTINGS_UI,
+                                        position_changed_cb,
+                                        notebook);
   g_signal_handlers_disconnect_by_func (EPHY_SETTINGS_UI,
                                         show_tabs_changed_cb,
                                         notebook);
+
   g_list_free (notebook->focused_pages);
 
   G_OBJECT_CLASS (ephy_notebook_parent_class)->finalize (object);
@@ -530,11 +548,9 @@ tab_label_style_set_cb (GtkWidget *hbox,
   char_width = pango_font_metrics_get_approximate_digit_width (metrics);
   pango_font_metrics_unref (metrics);
 
-  gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (hbox),
-                                     GTK_ICON_SIZE_MENU, &w, &h);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
 
-  gtk_widget_set_size_request
-    (hbox, TAB_WIDTH_N_CHARS * PANGO_PIXELS (char_width) + 2 * w, -1);
+  gtk_widget_set_size_request (hbox, TAB_WIDTH_N_CHARS * PANGO_PIXELS (char_width) + 2 * w, -1);
 
   button = g_object_get_data (G_OBJECT (hbox), "close-button");
   gtk_widget_set_size_request (button, w + 2, h + 2);
@@ -570,7 +586,6 @@ build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
   label = gtk_label_new (NULL);
   gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
   gtk_label_set_single_line_mode (GTK_LABEL (label), TRUE);
-  gtk_misc_set_padding (GTK_MISC (label), 0, 0);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -584,7 +599,7 @@ build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
   gtk_button_set_relief (GTK_BUTTON (close_button),
                          GTK_RELIEF_NONE);
   /* don't allow focus on the close button */
-  gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
+  gtk_widget_set_focus_on_click (close_button, FALSE);
 
   gtk_widget_set_name (close_button, "ephy-tab-close-button");
 
@@ -678,7 +693,8 @@ ephy_notebook_insert_page (GtkNotebook *gnotebook,
   gtk_notebook_set_tab_detachable (gnotebook, tab_widget, TRUE);
   gtk_container_child_set (GTK_CONTAINER (gnotebook),
                            GTK_WIDGET (tab_widget),
-                           "tab-expand", TRUE,
+                           "tab-expand", g_settings_get_boolean (EPHY_SETTINGS_UI,
+                                                                 EPHY_PREFS_UI_EXPAND_TABS_BAR),
                            NULL);
 
   return position;
@@ -701,7 +717,8 @@ ephy_notebook_add_tab (EphyNotebook *notebook,
 
   gtk_container_child_set (GTK_CONTAINER (notebook),
                            GTK_WIDGET (embed),
-                           "tab-expand", TRUE,
+                           "tab-expand", g_settings_get_boolean (EPHY_SETTINGS_UI,
+                                                                 EPHY_PREFS_UI_EXPAND_TABS_BAR),
                            NULL);
 
   if (jump_to) {
