@@ -2,22 +2,23 @@
 /*
  *  Copyright © 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_PRIVATE_H
-#define EPHY_PRIVATE_H
+#pragma once
 
 #include "ephy-embed.h"
 #include "ephy-embed-event.h"
@@ -29,9 +30,9 @@
 
 #include <gtk/gtk.h>
 
-/* EphyWindow */
+G_BEGIN_DECLS
 
-GtkActionGroup          *ephy_window_get_toolbar_action_group (EphyWindow               *window);
+/* EphyWindow */
 
 EphyLocationController  *ephy_window_get_location_controller  (EphyWindow               *window);
 
@@ -61,5 +62,4 @@ void                     _ephy_shell_create_instance          (EphyEmbedShellMod
 
 void                     ephy_session_clear                   (EphySession *session);
 
-#endif
-
+G_END_DECLS
