@@ -1,24 +1,26 @@
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2002 Jorn Baayen
  *  Copyright © 2003 Marco Pesenti Gritti
  *  Copyright © 2003 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_SESSION_H
-#define EPHY_SESSION_H
+#pragma once
 
 #include "ephy-window.h"
 
@@ -26,33 +28,11 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_TYPE_SESSION		(ephy_session_get_type ())
-#define EPHY_SESSION(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_SESSION, EphySession))
-#define EPHY_SESSION_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_SESSION, EphySessionClass))
-#define EPHY_IS_SESSION(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_SESSION))
-#define EPHY_IS_SESSION_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SESSION))
-#define EPHY_SESSION_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SESSION, EphySessionClass))
+#define EPHY_TYPE_SESSION (ephy_session_get_type ())
 
-typedef struct _EphySession		EphySession;
-typedef struct _EphySessionPrivate	EphySessionPrivate;
-typedef struct _EphySessionClass	EphySessionClass;
+G_DECLARE_FINAL_TYPE (EphySession, ephy_session, EPHY, SESSION, GObject)
 
-struct _EphySession
-{
-        GObject parent;
-
-	/*< private >*/
-        EphySessionPrivate *priv;
-};
-
-struct _EphySessionClass
-{
-        GObjectClass parent_class;
-};
-
-GType            ephy_session_get_type                (void);
-
-void 	         ephy_session_save		      (EphySession *session);
+void             ephy_session_save                    (EphySession *session);
 void             ephy_session_load                    (EphySession *session,
                                                        const char *filename,
                                                        guint32 user_time,
@@ -88,5 +68,3 @@ void             ephy_session_undo_close_tab          (EphySession *session);
 gboolean         ephy_session_get_can_undo_tab_closed (EphySession *session);
 
 G_END_DECLS
-
-#endif
