@@ -4,38 +4,40 @@
  *  Copyright © 2003, 2004, 2006 Christian Persch
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 #include "ephy-shell.h"
 
-#include "ephy-bookmarks-editor.h"
-#include "ephy-bookmarks-import.h"
 #include "ephy-debug.h"
 #include "ephy-downloads-manager.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
 #include "ephy-gui.h"
+#include "ephy-header-bar.h"
 #include "ephy-history-window.h"
-#include "ephy-home-action.h"
 #include "ephy-lockdown.h"
 #include "ephy-prefs.h"
 #include "ephy-private.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
+#include "ephy-title-box.h"
+#include "ephy-title-widget.h"
 #include "ephy-type-builtins.h"
 #include "ephy-web-view.h"
 #include "ephy-window.h"
@@ -50,11 +52,11 @@ struct _EphyShell {
   EphyEmbedShell parent_instance;
 
   EphySession *session;
+  EphySyncService *sync_service;
   GList *windows;
   GObject *lockdown;
-  EphyBookmarks *bookmarks;
+  EphyBookmarksManager *bookmarks_manager;
   GNetworkMonitor *network_monitor;
-  GtkWidget *bme;
   GtkWidget *history_window;
   GObject *prefs_dialog;
   EphyShellStartupContext *local_startup_context;
@@ -143,7 +145,7 @@ new_window (GSimpleAction *action,
             GVariant      *parameter,
             gpointer       user_data)
 {
-  window_cmd_file_new_window (NULL, NULL);
+  window_cmd_new_window (NULL, NULL, NULL);
 }
 
 static void
@@ -151,7 +153,7 @@ new_incognito_window (GSimpleAction *action,
                       GVariant      *parameter,
                       gpointer       user_data)
 {
-  window_cmd_file_new_incognito_window (NULL, NULL);
+  window_cmd_new_incognito_window (NULL, NULL, NULL);
 }
 
 static void
@@ -159,15 +161,7 @@ reopen_closed_tab (GSimpleAction *action,
                    GVariant      *parameter,
                    gpointer       user_data)
 {
-  window_cmd_undo_close_tab (NULL, NULL);
-}
-
-static void
-show_bookmarks (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       user_data)
-{
-  window_cmd_edit_bookmarks (NULL, NULL);
+  window_cmd_reopen_closed_tab (NULL, NULL, NULL);
 }
 
 static void
@@ -179,7 +173,7 @@ show_history (GSimpleAction *action,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
 
-  window_cmd_edit_history (NULL, EPHY_WINDOW (window));
+  window_cmd_show_history (NULL, NULL, EPHY_WINDOW (window));
 }
 
 static void
@@ -191,7 +185,7 @@ show_preferences (GSimpleAction *action,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
 
-  window_cmd_edit_preferences (NULL, EPHY_WINDOW (window));
+  window_cmd_show_preferences (NULL, NULL, EPHY_WINDOW (window));
 }
 
 static void
@@ -203,7 +197,7 @@ show_shortcuts (GSimpleAction *action,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
 
-  window_cmd_help_shortcuts (NULL, GTK_WIDGET (window));
+  window_cmd_show_shortcuts (NULL, NULL, EPHY_WINDOW (window));
 }
 
 static void
@@ -215,7 +209,7 @@ show_help (GSimpleAction *action,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
 
-  window_cmd_help_contents (NULL, GTK_WIDGET (window));
+  window_cmd_show_help (NULL, NULL, GTK_WIDGET (window));
 }
 
 static void
@@ -227,7 +221,7 @@ show_about (GSimpleAction *action,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
 
-  window_cmd_help_about (NULL, GTK_WIDGET (window));
+  window_cmd_show_about (NULL, NULL, GTK_WIDGET (window));
 }
 
 static void
@@ -235,13 +229,12 @@ quit_application (GSimpleAction *action,
                   GVariant      *parameter,
                   gpointer       user_data)
 {
-  window_cmd_file_quit (NULL, NULL);
+  window_cmd_quit (NULL, NULL, NULL);
 }
 
 static GActionEntry app_entries[] = {
   { "new-window", new_window, NULL, NULL, NULL },
   { "new-incognito", new_incognito_window, NULL, NULL, NULL },
-  { "bookmarks", show_bookmarks, NULL, NULL, NULL },
   { "history", show_history, NULL, NULL, NULL },
   { "preferences", show_preferences, NULL, NULL, NULL },
   { "shortcuts", show_shortcuts, NULL, NULL, NULL },
@@ -250,6 +243,11 @@ static GActionEntry app_entries[] = {
   { "quit", quit_application, NULL, NULL, NULL },
 };
 
+static GActionEntry app_mode_app_entries[] = {
+  { "about", show_about, NULL, NULL, NULL },
+  { "quit", quit_application, NULL, NULL, NULL },
+};
+
 static GActionEntry app_normal_mode_entries[] = {
   { "reopen-closed-tab", reopen_closed_tab, NULL, NULL, NULL },
 };
@@ -289,6 +287,7 @@ ephy_shell_startup (GApplication *application)
 {
   EphyEmbedShell *embed_shell = EPHY_EMBED_SHELL (application);
   EphyEmbedShellMode mode;
+  GtkBuilder *builder;
 
   G_APPLICATION_CLASS (ephy_shell_parent_class)->startup (application);
 
@@ -298,10 +297,14 @@ ephy_shell_startup (GApplication *application)
                     G_CALLBACK (download_started_cb),
                     application);
 
-  mode = ephy_embed_shell_get_mode (embed_shell);
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_resource (builder,
+                                 "/org/gnome/epiphany/epiphany-application-menu.ui",
+                                 NULL);
 
+  mode = ephy_embed_shell_get_mode (embed_shell);
   if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION) {
-    GtkBuilder *builder;
+    EphySyncService *service;
 
     g_action_map_add_action_entries (G_ACTION_MAP (application),
                                      app_entries, G_N_ELEMENTS (app_entries),
@@ -319,14 +322,26 @@ ephy_shell_startup (GApplication *application)
                               G_BINDING_SYNC_CREATE);
     }
 
+    /* Start the periodical sync now. */
+    service = ephy_sync_service_new ();
+    ephy_sync_service_start_periodical_sync (service, TRUE);
+    ephy_shell->sync_service = service;
+
     builder = gtk_builder_new ();
     gtk_builder_add_from_resource (builder,
                                    "/org/gnome/epiphany/epiphany-application-menu.ui",
                                    NULL);
     gtk_application_set_app_menu (GTK_APPLICATION (application),
                                   G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu")));
-    g_object_unref (builder);
+  } else {
+    g_action_map_add_action_entries (G_ACTION_MAP (application),
+                                     app_mode_app_entries, G_N_ELEMENTS (app_mode_app_entries),
+                                     application);
+    gtk_application_set_app_menu (GTK_APPLICATION (application),
+                                  G_MENU_MODEL (gtk_builder_get_object (builder, "app-mode-app-menu")));
   }
+
+  g_object_unref (builder);
 }
 
 static void
@@ -577,11 +592,10 @@ ephy_shell_dispose (GObject *object)
 
   g_clear_object (&shell->session);
   g_clear_object (&shell->lockdown);
-  g_clear_pointer (&shell->bme, gtk_widget_destroy);
   g_clear_pointer (&shell->history_window, gtk_widget_destroy);
   g_clear_object (&shell->prefs_dialog);
-  g_clear_object (&shell->bookmarks);
   g_clear_object (&shell->network_monitor);
+  g_clear_object (&shell->sync_service);
 
   g_slist_free_full (shell->open_uris_idle_ids, remove_open_uris_idle_cb);
   shell->open_uris_idle_ids = NULL;
@@ -678,8 +692,6 @@ ephy_shell_new_tab_full (EphyShell      *shell,
   gtk_widget_show (GTK_WIDGET (embed));
   ephy_embed_container_add_child (EPHY_EMBED_CONTAINER (window), embed, position, jump_to);
 
-  ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
-
   if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0 &&
       ephy_embed_shell_get_mode (embed_shell) != EPHY_EMBED_SHELL_MODE_TEST) {
     gtk_widget_show (GTK_WIDGET (window));
@@ -730,18 +742,38 @@ ephy_shell_get_session (EphyShell *shell)
 }
 
 /**
- * ephy_shell_get_bookmarks:
+ * ephy_shell_get_sync_service:
+ * @shell: the #EphyShell
  *
- * Return value: (transfer none):
+ * Returns the sync service.
+ *
+ * Return value: (transfer none): the global #EphySyncService
  **/
-EphyBookmarks *
-ephy_shell_get_bookmarks (EphyShell *shell)
+EphySyncService *
+ephy_shell_get_sync_service (EphyShell *shell)
 {
-  if (shell->bookmarks == NULL) {
-    shell->bookmarks = ephy_bookmarks_new ();
-  }
+  g_return_val_if_fail (EPHY_IS_SHELL (shell), NULL);
 
-  return shell->bookmarks;
+  return shell->sync_service;
+}
+
+/**
+ * ephy_shell_get_bookmarks_manager:
+ * @shell: the #EphyShell
+ *
+ * Returns bookmarks manager.
+ *
+ * Return value: (transfer none): An #EphyBookmarksManager.
+ */
+EphyBookmarksManager *
+ephy_shell_get_bookmarks_manager (EphyShell *shell)
+{
+  g_return_val_if_fail (EPHY_IS_SHELL (shell), NULL);
+
+  if (shell->bookmarks_manager == NULL)
+    shell->bookmarks_manager = EPHY_BOOKMARKS_MANAGER (g_object_new (EPHY_TYPE_BOOKMARKS_MANAGER, NULL));
+
+  return shell->bookmarks_manager;
 }
 
 /**
@@ -758,25 +790,6 @@ ephy_shell_get_net_monitor (EphyShell *shell)
   return shell->network_monitor;
 }
 
-/**
- * ephy_shell_get_bookmarks_editor:
- *
- * Return value: (transfer none):
- **/
-GtkWidget *
-ephy_shell_get_bookmarks_editor (EphyShell *shell)
-{
-  EphyBookmarks *bookmarks;
-
-  if (shell->bme == NULL) {
-    bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-    g_assert (bookmarks != NULL);
-    shell->bme = ephy_bookmarks_editor_new (bookmarks);
-  }
-
-  return shell->bme;
-}
-
 /**
  * ephy_shell_get_history_window:
  *
@@ -958,10 +971,15 @@ static gboolean
 ephy_shell_open_uris_idle (OpenURIsData *data)
 {
   EphyEmbed *embed = NULL;
+  EphyHeaderBar *header_bar;
+  EphyTitleWidget *title_widget;
+  EphyEmbedShellMode mode;
   EphyNewTabFlags page_flags = 0;
   gboolean reusing_empty_tab = FALSE;
   const char *url;
 
+  mode = ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (data->shell));
+
   if (!data->window)
     data->window = ephy_window_new ();
   else if (data->previous_embed)
@@ -974,7 +992,7 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
   }
 
   if (!reusing_empty_tab) {
-    embed = ephy_shell_new_tab_full (ephy_shell_get_default (),
+    embed = ephy_shell_new_tab_full (data->shell,
                                      NULL, NULL,
                                      data->window,
                                      data->previous_embed,
@@ -990,13 +1008,18 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
     if (reusing_empty_tab || data->flags & EPHY_NEW_TAB_JUMP)
       gtk_widget_grab_focus (GTK_WIDGET (embed));
 
-    if (data->flags & EPHY_NEW_TAB_JUMP && ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (data->shell)) != EPHY_EMBED_SHELL_MODE_TEST)
+    if (data->flags & EPHY_NEW_TAB_JUMP && mode != EPHY_EMBED_SHELL_MODE_TEST)
       gtk_window_present_with_time (GTK_WINDOW (data->window), data->user_time);
   } else {
     ephy_web_view_load_homepage (ephy_embed_get_web_view (embed));
     ephy_window_activate_location (data->window);
   }
 
+  /* Set address from the very beginning. Looks odd in app mode if it appears later on. */
+  header_bar = EPHY_HEADER_BAR (ephy_window_get_header_bar (data->window));
+  title_widget = ephy_header_bar_get_title_widget (header_bar);
+  ephy_title_widget_set_address (title_widget, url);
+
   data->current_uri++;
   data->previous_embed = embed;
 
