@@ -4,27 +4,29 @@
  *  Copyright © 2003, 2004, 2006 Christian Persch
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_SHELL_H
-#define EPHY_SHELL_H
+#pragma once
 
-#include "ephy-bookmarks.h"
+#include "ephy-bookmarks-manager.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed.h"
 #include "ephy-session.h"
+#include "ephy-sync-service.h"
 #include "ephy-window.h"
 
 #include <webkit2/webkit2.h>
@@ -98,9 +100,9 @@ EphySession     *ephy_shell_get_session                  (EphyShell *shell);
 
 GNetworkMonitor *ephy_shell_get_net_monitor              (EphyShell *shell);
 
-EphyBookmarks   *ephy_shell_get_bookmarks                (EphyShell *shell);
+EphyBookmarksManager *ephy_shell_get_bookmarks_manager   (EphyShell *shell);
 
-GtkWidget       *ephy_shell_get_bookmarks_editor         (EphyShell *shell);
+EphySyncService *ephy_shell_get_sync_service             (EphyShell *shell);
 
 GtkWidget       *ephy_shell_get_history_window           (EphyShell *shell);
 
@@ -115,5 +117,3 @@ void            ephy_shell_open_uris                    (EphyShell *shell,
                                                          EphyStartupFlags startup_flags,
                                                          guint32 user_time);
 G_END_DECLS
-
-#endif
