@@ -1,19 +1,21 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2013 Red Hat, Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -26,11 +28,11 @@
 #include <libsecret/secret.h>
 
 #include "ephy-form-auth-data.h"
-#include "ephy-uri-helpers.h"
+#include "ephy-string.h"
 #include "passwords-dialog.h"
 
 typedef enum {
-  COL_PASSWORDS_ORIGIN,
+  COL_PASSWORDS_HOST,
   COL_PASSWORDS_USER,
   COL_PASSWORDS_PASSWORD,
   COL_PASSWORDS_INVISIBLE,
@@ -326,7 +328,7 @@ on_passwords_treeview_button_press_event (GtkWidget           *widget,
 
     menu = gtk_menu_new_from_model (dialog->treeview_popup_menu_model);
     gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (dialog), NULL);
-    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, event->button, event->time);
+    gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent *)event);
     return TRUE;
   }
 
@@ -402,30 +404,26 @@ secrets_search_ready_cb (GObject             *source_object,
     GHashTable *attributes = NULL;
     const char *username = NULL;
     const char *password = NULL;
-    char *origin = NULL;
+    char *host = NULL;
     GtkTreeIter iter;
 
     attributes = secret_item_get_attributes (item);
     username = g_hash_table_lookup (attributes, USERNAME_KEY);
+    host = ephy_string_get_host_name (g_hash_table_lookup (attributes, URI_KEY));
     value = secret_item_get_secret (item);
     password = secret_value_get (value, NULL);
-    origin = ephy_uri_to_security_origin (g_hash_table_lookup (attributes, URI_KEY));
-    if (origin == NULL) {
-      g_hash_table_unref (attributes);
-      continue;
-    }
 
     gtk_list_store_insert_with_values (GTK_LIST_STORE (dialog->liststore),
                                        &iter,
                                        -1,
-                                       COL_PASSWORDS_ORIGIN, origin,
+                                       COL_PASSWORDS_HOST, host,
                                        COL_PASSWORDS_USER, username,
                                        COL_PASSWORDS_PASSWORD, password,
                                        COL_PASSWORDS_INVISIBLE, "●●●●●●●●",
                                        COL_PASSWORDS_DATA, item,
                                        -1);
 
-    g_free (origin);
+    g_free (host);
     g_hash_table_unref (attributes);
   }
 
@@ -467,23 +465,23 @@ row_visible_func (GtkTreeModel        *model,
                   EphyPasswordsDialog *dialog)
 {
   char *username;
-  char *origin;
+  char *host;
   gboolean visible = FALSE;
 
   if (dialog->search_text == NULL)
     return TRUE;
 
   gtk_tree_model_get (model, iter,
-                      COL_PASSWORDS_ORIGIN, &origin,
+                      COL_PASSWORDS_HOST, &host,
                       COL_PASSWORDS_USER, &username,
                       -1);
 
-  if (origin != NULL && g_strrstr (origin, dialog->search_text) != NULL)
+  if (host != NULL && g_strrstr (host, dialog->search_text) != NULL)
     visible = TRUE;
   else if (username != NULL && g_strrstr (username, dialog->search_text) != NULL)
     visible = TRUE;
 
-  g_free (origin);
+  g_free (host);
   g_free (username);
 
   return visible;
